#!/usr/bin/env python
# coding: utf-8

#########################################################################
#########################################################################

"""
   File Name: __init__.py
      Author: Wan Ji
      E-mail: wanji@live.com
  Created on: Tue Nov  4 09:00:29 2014 CST
"""
DESCRIPTION = """
"""
import indexer
import distance
